@@ -106,18 +106,6 @@ enum HEVC_BRC_FRAME_TYPE
     HEVC_BRC_FRAME_TYPE_INVALID
 };
 
-//!
-//! \enum     HEVC_PYRAMID_LAYER_NUM
-//!
-enum HEVC_PYRAMID_LAYER_NUM
-{
-    HEVC_PYRAMID_LAYER_NUM_0 = 0,
-    HEVC_PYRAMID_LAYER_NUM_1 = 1,
-    HEVC_PYRAMID_LAYER_NUM_2 = 2,
-    HEVC_PYRAMID_LAYER_NUM_3 = 3,
-    HEVC_PYRAMID_LAYER_NUM_4 = 4
-};
-
 typedef enum
 {
     ENCODE_HEVC_BIT_DEPTH_8     = 0,
