@@ -238,10 +238,10 @@ MOS_STATUS SfcRenderBase::SetIefStateCscParams(
     {
         psfcStateParams->bCSCEnable = true;
         pIEFStateParams->bCSCEnable = true;
-        if (m_bVdboxToSfc && m_videoConfig.codecStandard == CODECHAL_JPEG)
+        if (m_bVdboxToSfc)
         {
             m_cscInputSwapNeeded = false;
-            if (m_videoConfig.jpeg.jpegChromaType == jpegRGB)
+            if (m_videoConfig.jpeg.jpegChromaType == jpegRGB && m_videoConfig.codecStandard == CODECHAL_JPEG)
             {
                 m_cscCoeff[0] = 1.000000000f;
                 m_cscCoeff[1] = 0.000000000f;
@@ -586,41 +586,6 @@ MOS_STATUS SfcRenderBase::SetupSfcState(PVP_SURFACE targetSurface)
 
     VP_RENDER_CHK_STATUS_RETURN(SetupScalabilityParams());
 
-    // Decompress resource if surfaces need write from a un-align offset
-    if ((targetSurface->osSurface->CompressionMode != MOS_MMC_DISABLED)        &&
-        IsSFCUncompressedWriteNeeded(targetSurface))
-    {
-        MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
-        MOS_SURFACE details = {};
-
-        eStatus = m_osInterface->pfnGetResourceInfo(m_osInterface, &targetSurface->osSurface->OsResource, &details);
-
-        if (eStatus != MOS_STATUS_SUCCESS)
-        {
-            VP_RENDER_ASSERTMESSAGE("Get SFC target surface resource info failed.");
-        }
-
-        if (!targetSurface->osSurface->OsResource.bUncompressedWriteNeeded)
-        {
-            eStatus = m_osInterface->pfnDecompResource(m_osInterface, &targetSurface->osSurface->OsResource);
-
-            if (eStatus != MOS_STATUS_SUCCESS)
-            {
-                VP_RENDER_ASSERTMESSAGE("inplace decompression failed for sfc target.");
-            }
-            else
-            {
-                VP_RENDER_NORMALMESSAGE("inplace decompression enabled for sfc target RECT is not compression block align.");
-                targetSurface->osSurface->OsResource.bUncompressedWriteNeeded = 1;
-            }
-        }
-    }
-
-    if (targetSurface->osSurface->OsResource.bUncompressedWriteNeeded)
-    {
-        m_renderData.sfcStateParams->MMCMode = MOS_MMC_RC;
-    }
-
     return eStatus;
 }
 
@@ -1472,7 +1437,7 @@ MOS_STATUS SfcRenderBase::AllocateResources()
     size = GetIefLineBufferSize(false, m_renderData.sfcStateParams->dwScaledRegionHeight);
     VP_RENDER_CHK_STATUS_RETURN(AllocateLineBufferArray(m_IEFLineBufferSurfaceArray, size, "SfcIEFLineBufferSurface"));
 
-    if (m_renderData.sfcStateParams->dwScaledRegionHeight > SFC_LINEBUFEER_SIZE_LIMITED)
+    if (m_bVdboxToSfc || m_renderData.sfcStateParams->dwScaledRegionHeight > SFC_LINEBUFEER_SIZE_LIMITED)
     {
         // Allocate SFD Line Buffer surface
         size = GetSfdLineBufferSize(false, m_renderData.sfcStateParams->OutputFrameFormat, m_renderData.sfcStateParams->dwScaledRegionWidth, m_renderData.sfcStateParams->dwScaledRegionHeight);
